@@ -8,7 +8,7 @@ import (
 
 	"github.com/twpayne/go-vfs/v5"
 
-	"github.com/twpayne/chezmoi/internal/chezmoilog"
+	"chezmoi.io/chezmoi/internal/chezmoilog"
 )
 
 // A DebugSystem logs all calls to a System.
@@ -17,7 +17,8 @@ type DebugSystem struct {
 	system System
 }
 
-// NewDebugSystem returns a new DebugSystem that logs methods on system to logger.
+// NewDebugSystem returns a new DebugSystem that logs methods on system to
+// logger.
 func NewDebugSystem(system System, logger *slog.Logger) *DebugSystem {
 	return &DebugSystem{
 		logger: logger,
