@@ -9,8 +9,15 @@ import (
 	"github.com/go-git/go-git/v5/plumbing/filemode"
 	"github.com/go-git/go-git/v5/plumbing/format/diff"
 	znkrdiff "znkr.io/diff"
+	znkrtextdiff "znkr.io/diff/textdiff"
 )
 
+var gitDiffOperation = [...]diff.Operation{
+	znkrdiff.Delete: diff.Delete,
+	znkrdiff.Match:  diff.Equal,
+	znkrdiff.Insert: diff.Add,
+}
+
 // A gitDiffChunk implements the
 // github.com/go-git/go-git/v5/plumbing/format/diff.Chunk interface.
 type gitDiffChunk struct {
@@ -18,8 +25,8 @@ type gitDiffChunk struct {
 	operation diff.Operation
 }
 
-func (c gitDiffChunk) Content() string      { return c.content }
-func (c gitDiffChunk) Type() diff.Operation { return c.operation }
+func (c *gitDiffChunk) Content() string      { return c.content }
+func (c *gitDiffChunk) Type() diff.Operation { return c.operation }
 
 // A gitDiffFile implements the
 // github.com/go-git/go-git/v5/plumbing/format/diff.File interface.
@@ -36,12 +43,12 @@ func (f *gitDiffFile) Path() string            { return f.relPath.String() }
 // A gitDiffFilePatch implements the
 // github.com/go-git/go-git/v5/plumbing/format/diff.FilePatch interface.
 type gitDiffFilePatch struct {
-	isBinary bool
+	binary   bool
 	from, to diff.File
 	chunks   []diff.Chunk
 }
 
-func (fp *gitDiffFilePatch) IsBinary() bool              { return fp.isBinary }
+func (fp *gitDiffFilePatch) IsBinary() bool              { return fp.binary }
 func (fp *gitDiffFilePatch) Files() (from, to diff.File) { return fp.from, fp.to }
 func (fp *gitDiffFilePatch) Chunks() []diff.Chunk        { return fp.chunks }
 
@@ -94,10 +101,10 @@ func DiffPatch(path RelPath, fromData []byte, fromMode fs.FileMode, toData []byt
 	return &gitDiffPatch{
 		filePatches: []diff.FilePatch{
 			&gitDiffFilePatch{
-				isBinary: isBinary,
-				from:     from,
-				to:       to,
-				chunks:   chunks,
+				binary: isBinary,
+				from:   from,
+				to:     to,
+				chunks: chunks,
 			},
 		},
 	}, nil
@@ -106,29 +113,36 @@ func DiffPatch(path RelPath, fromData []byte, fromMode fs.FileMode, toData []byt
 // diffChunks returns the
 // github.com/go-git/go-git/v5/plumbing/format/diff.Chunks required to transform
 // from into to.
+//
+// Nothing documents this, but go-git seems to depend on never encountering
+// consecutive edits of the same operation. This forces us to join the
+// individual edits into chunks.
 func diffChunks(from, to string) []diff.Chunk {
-	fromLines := withoutEmpty(strings.SplitAfter(from, "\n"))
-	toLines := withoutEmpty(strings.SplitAfter(to, "\n"))
-	edits := znkrdiff.Edits(fromLines, toLines, znkrdiff.Optimal())
-	chunks := make([]diff.Chunk, len(edits))
-	for i, edit := range edits {
-		switch edit.Op {
-		case znkrdiff.Delete:
-			chunks[i] = gitDiffChunk{
-				content:   edit.X,
-				operation: diff.Delete,
-			}
-		case znkrdiff.Insert:
-			chunks[i] = gitDiffChunk{
-				content:   edit.Y,
-				operation: diff.Add,
-			}
-		case znkrdiff.Match:
-			chunks[i] = gitDiffChunk{
-				content:   edit.X,
-				operation: diff.Equal,
+	edits := znkrtextdiff.Edits(from, to, znkrdiff.Minimal())
+	if len(edits) == 0 {
+		return nil
+	}
+	var chunks []diff.Chunk
+	lastOp := edits[0].Op
+	var sb strings.Builder
+	for _, edit := range edits {
+		if edit.Op != lastOp {
+			if content := sb.String(); content != "" {
+				chunks = append(chunks, &gitDiffChunk{
+					content:   content,
+					operation: gitDiffOperation[lastOp],
+				})
 			}
+			lastOp = edit.Op
+			sb.Reset()
 		}
+		sb.WriteString(edit.Line)
+	}
+	if content := sb.String(); content != "" {
+		chunks = append(chunks, &gitDiffChunk{
+			content:   content,
+			operation: gitDiffOperation[lastOp],
+		})
 	}
 	return chunks
 }
@@ -147,16 +161,3 @@ func diffFileMode(mode fs.FileMode) (filemode.FileMode, error) {
 func isBinary(data []byte) bool {
 	return len(data) != 0 && !strings.HasPrefix(http.DetectContentType(data), "text/")
 }
-
-func withoutEmpty(s []string) []string {
-	switch {
-	case len(s) == 0:
-		return nil
-	case s[0] == "":
-		return s[1:]
-	case s[len(s)-1] == "":
-		return s[:len(s)-1]
-	default:
-		return s
-	}
-}
