@@ -38,8 +38,8 @@ func (p RelPath) Dir() RelPath {
 	return NewRelPath(path.Dir(p.relPath))
 }
 
-// Empty returns if p is empty.
-func (p RelPath) Empty() bool {
+// IsEmpty returns if p is empty.
+func (p RelPath) IsEmpty() bool {
 	return p.relPath == ""
 }
 
@@ -121,7 +121,7 @@ func (p RelPath) String() string {
 // TrimDirPrefix trims prefix from p.
 func (p RelPath) TrimDirPrefix(dirPrefix RelPath) (RelPath, error) {
 	if !p.HasDirPrefix(dirPrefix) {
-		return EmptyRelPath, &notInRelDirError{
+		return EmptyRelPath, &NotInRelDirError{
 			pathRelPath: p,
 			dirRelPath:  dirPrefix,
 		}
